build_boot_manifest

Function build_boot_manifest 

pub fn build_boot_manifest<J, S>(
    app_version: Option<&str>,
    git_sha: Option<&str>,
    cron_registry: Option<&CronRegistry<S>>,
) -> AppManifest
where J: JobRegistry<S>, S: AppState,
Build an AppManifest from a job registry and (optionally) a cron registry.

Job names come from JobRegistry::job_names (generated by impl_job_registry!). Cron schedule strings come from crate::cron::CronRegistry::entries: the Duration Debug form for interval schedules (e.g. "300s") and the original expression for cron expression schedules.

Most apps should call send_boot_manifest instead; this is exposed for callers that want to inspect or customize the manifest before sending it with send_manifest (e.g. attaching a base_url and HttpMonitor declarations).